@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="az">
 <context>
     <name>CMainWindow</name>
     <message>
@@ -259,6 +261,14 @@
         <source>None</source>
         <translation>Heç biri</translation>
     </message>
+    <message>
+        <source>mp4</source>
+        <translation>mp4</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
 </context>
 <context>
     <name>filterPreviewButton</name>
@@ -341,4 +351,4 @@
         <translation type="vanished">Çəkimi saxlamaq</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
