@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="lt">
 <context>
     <name>CMainWindow</name>
     <message>
@@ -84,10 +86,6 @@
         <translation>Užverti
 </translation>
     </message>
-    <message>
-        <source>Invalid folder</source>
-        <translation>Neteisingas aplankas</translation>
-    </message>
     <message>
         <source>Open folder</source>
         <translation>Atverti folderį
@@ -159,10 +157,6 @@
         <source>File not saved</source>
         <translation> failas nebuvo išsaugotas</translation>
     </message>
-    <message>
-        <source>Save to:</source>
-        <translation>Išsaugoti į:</translation>
-    </message>
     <message>
         <source>Photo:</source>
         <translation>Vaizdas:</translation>
@@ -175,10 +169,6 @@
         <source>Resolution settings</source>
         <translation>Nustatymai apie resoliuciją</translation>
     </message>
-    <message>
-        <source>Resolution:</source>
-        <translation>Raiškė:</translation>
-    </message>
     <message>
         <source>Photos:</source>
         <translation>Vaizdai:</translation>
@@ -265,14 +255,6 @@
 </context>
 <context>
     <name>ThumbnailsBar</name>
-    <message>
-        <source>Take photo</source>
-        <translation>Fotografuoti</translation>
-    </message>
-    <message>
-        <source>Record video</source>
-        <translation>Įrašyti vaizdo įrašą</translation>
-    </message>
     <message>
         <source>Stop taking photos</source>
         <translation type="vanished">Stošis nuo vaizdo įrašymo</translation>
@@ -284,6 +266,14 @@
         <source>None</source>
         <translation>Nėra</translation>
     </message>
+    <message>
+        <source>mp4</source>
+        <translation>mp4</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
 </context>
 <context>
     <name>filterPreviewButton</name>
